@@ -1,15 +1,12 @@
-import argparse, shlex, shutil, subprocess
+import argparse, shlex, shutil
 from pathlib import Path
-from typing import Dict, Iterable, List
+from typing import Dict
 
-import ffmpeg
-import pandas as pd
-import sqlite_utils
+import ffmpeg, sqlite_utils
 from catt.api import CattDevice
 from rich.prompt import Confirm
 
-from xklb import paths, utils
-from xklb.db import connect_db
+from xklb import db, paths, utils
 from xklb.player import (
     delete_media,
     get_ordinal_media,
@@ -24,9 +21,7 @@ from xklb.player import (
     socket_play,
     watch_chromecast,
 )
-from xklb.utils import SC, cmd, log
-
-idle_mpv = lambda args: ["mpv", "--idle", f"--input-ipc-server={args.mpv_socket}"]
+from xklb.utils import DEFAULT_PLAY_QUEUE, SC, cmd, log
 
 
 def parse_args(action, default_db, default_chromecast=""):
@@ -151,10 +146,10 @@ def parse_args(action, default_db, default_chromecast=""):
 
     Repeat
 
-        lt                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
-        lt --limit 5        # listen to FIVE songs
-        lt -l inf -u random # listen to random songs indefinitely
-        lt -s infinite      # listen to songs from the band infinite
+        lb {action}                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
+        lb {action} --limit 5        # listen to FIVE songs
+        lb {action} -l inf -u random # listen to random songs indefinitely
+        lb {action} -s infinite      # listen to songs from the band infinite
 
     Constrain media by search:
 
@@ -207,7 +202,7 @@ def parse_args(action, default_db, default_chromecast=""):
 
         Bitrate information is not explicitly saved but you can use file size and duration as a proxy:
 
-        wt -w 'size/duration<50000'
+        lb {action} -w 'size/duration<50000'
 
     Constrain media to portrait orientation video:
 
@@ -297,7 +292,7 @@ def parse_args(action, default_db, default_chromecast=""):
         "--player-args-when-sub", "-player-sub", nargs="*", default=["--speed=1"], help=argparse.SUPPRESS
     )
     parser.add_argument(
-        "--player-args-when-no-sub", "-player-no-sub", nargs="*", default=["--speed=1.7"], help=argparse.SUPPRESS
+        "--player-args-when-no-sub", "-player-no-sub", nargs="*", default=["--speed=1.46"], help=argparse.SUPPRESS
     )
     parser.add_argument("--transcode", action="store_true", help=argparse.SUPPRESS)
 
@@ -337,9 +332,6 @@ def parse_args(action, default_db, default_chromecast=""):
         elif args.action in [SC.filesystem]:
             args.sort = ["sparseness, size"]
 
-    if args.random:
-        args.sort = ["random"]
-
     if args.sort:
         args.sort = " ".join(args.sort)
         args.sort = override_sort(args.sort)
@@ -603,12 +595,12 @@ def construct_search_bindings(args, bindings, cf, include_func, exclude_func):
         bindings[f"exclude{idx}"] = "%" + exc.replace(" ", "%").replace("%%", " ") + "%"
 
 
-def substring_search(args, cf, bindings):
-    if args.action == SC.listen:
-        construct_search_bindings(args, bindings, cf, audio_include_string, audio_exclude_string)
-    elif args.action == SC.watch:
+def search_substring(args, cf, bindings):
+    if args.action == SC.watch:
         construct_search_bindings(args, bindings, cf, video_include_string, video_exclude_string)
-    else:
+    elif args.action == SC.listen:
+        construct_search_bindings(args, bindings, cf, audio_include_string, audio_exclude_string)
+    else:  # args.action == SC.filesystem
         construct_search_bindings(args, bindings, cf, other_include_string, other_exclude_string)
 
 
@@ -624,13 +616,22 @@ def construct_fs_query(args):
     cf.extend([" and " + w for w in args.where])
 
     table = "media"
-    if args.include:
-        bindings["query"] = " AND ".join(args.include)
-        if args.exclude:
-            bindings["query"] += " NOT " + " NOT ".join(args.exclude)
-        table = "(" + args.db["media"].search_sql() + ")"
-    elif args.exclude:
-        substring_search(args, cf, bindings)
+    if args.db["media"].detect_fts():
+        if args.include:
+            table = db.fts_search(args, bindings)
+        elif args.exclude:
+            search_substring(args, cf, bindings)
+    else:
+        search_substring(args, cf, bindings)
+
+    if table == "media" and not args.print:
+        limit = 60_000
+        if args.random:
+            if args.include:
+                args.sort = "random(), " + args.sort
+            else:
+                limit = DEFAULT_PLAY_QUEUE * 2
+        cf.append(f"and rowid in (select rowid from media order by random() limit {limit})")
 
     args.sql_filter = " ".join(cf)
     args.sql_filter_bindings = bindings
@@ -663,9 +664,9 @@ def construct_fs_query(args):
     return query, bindings
 
 
-def process_playqueue(args):
-    args.db = connect_db(args)
-    query, bindings = construct_fs_query(args)
+def process_playqueue(args, construct_query=construct_fs_query):
+    args.db = db.connect(args)
+    query, bindings = construct_query(args)
 
     if args.print:
         return printer(args, query, bindings)
@@ -676,15 +677,12 @@ def process_playqueue(args):
         print("No media found")
         exit(2)
 
-    if args.interdimensional_cable:
-        subprocess.Popen(idle_mpv(args))
-
     try:
         for m in media:
             play(args, m)
     finally:
         if args.interdimensional_cable:
-            utils.pkill(idle_mpv(args), strict=False)
+            args.sock.send((f"raw quit \n").encode("utf-8"))
         Path(args.mpv_socket).unlink(missing_ok=True)
         if args.chromecast:
             Path(paths.CAST_NOW_PLAYING).unlink(missing_ok=True)
