@@ -11,8 +11,7 @@ from urllib.error import HTTPError
 import pandas as pd
 import yt_dlp
 
-from xklb import utils
-from xklb.db import connect_db, optimize_db
+from xklb import db, utils
 from xklb.paths import SUB_TEMP_DIR, sanitize_url
 from xklb.subtitle import subs_to_text
 from xklb.tube_actions import default_ydl_opts
@@ -51,7 +50,7 @@ def parse_args(action, usage):
         args.database = args.db
 
     Path(args.database).touch()
-    args.db = connect_db(args)
+    args.db = db.connect(args)
 
     ydl_opts = {**default_ydl_opts, **args.yt_dlp_config}
     log.info(utils.dict_filter_bool(ydl_opts))
@@ -375,21 +374,20 @@ def get_extra_metadata(args, playlist_path) -> Union[List[Dict], None]:
 def get_playlists(args, include_playlistless_media=True):
     try:
         if include_playlistless_media:
-            known_playlists = utils.single_column_tolist(
-                args.db.execute("select path from playlists order by random()").fetchall(), "path"
-            )
+            known_playlists = [d["path"] for d in args.db.query("select path from playlists order by random()")]
+
         else:
-            known_playlists = utils.single_column_tolist(
-                args.db.execute(
+            known_playlists = [
+                d["playlist_path"]
+                for d in args.db.query(
                     """
                     select playlist_path from media
                     group by playlist_path
                     having count(playlist_path) > 1
                     order by random()
                     """
-                ).fetchall(),
-                "playlist_path",
-            )
+                )
+            ]
     except OperationalError:
         known_playlists = []
     return known_playlists
@@ -475,4 +473,4 @@ def tube_update():
             log.warning("Getting extra metadata")
             get_extra_metadata(args, playlist)
 
-    optimize_db(args)
+    db.optimize(args)
